%
% Copyright (c) 2015, Yarpiz (www.yarpiz.com)
% All rights reserved. Please read the "license.txt" for license terms.
%
% Project Code: YPAP113
% Project Title: Solving Economic Dispatching using Nested PSO in MATLAB
% Publisher: Yarpiz (www.yarpiz.com)
% 
% Developer: S. Mostapha Kalami Heris (Member of Yarpiz Team)
% 
% Contact Info: sm.kalami@gmail.com, info@yarpiz.com
%

function intmodel=CreateInternalModel(k,extmodel)

    intmodel.PD=extmodel.PD;

    nPlant=numel(k);
    
    intmodel.nPlant=nPlant;
    
    Plants=extmodel.Plants;
    EmptyPlant=extmodel.EmptyPlant;
    
    intmodel.Plants.Pmin=zeros(1,nPlant);
    intmodel.Plants.Pmax=zeros(1,nPlant);
    intmodel.Plants.alpha=zeros(1,nPlant);
    intmodel.Plants.beta=zeros(1,nPlant);
    intmodel.Plants.gamma=zeros(1,nPlant);
    intmodel.Plants.PZ=cell(1,nPlant);

    for i=1:nPlant
        ki=k(i);
        if ki==0
            % Set Plant #i to be Empty
            intmodel.Plants.Pmin(i)=EmptyPlant.Pmin;
            intmodel.Plants.Pmax(i)=EmptyPlant.Pmax;
            intmodel.Plants.alpha(i)=EmptyPlant.alpha;
            intmodel.Plants.beta(i)=EmptyPlant.beta;
            intmodel.Plants.gamma(i)=EmptyPlant.gamma;
            intmodel.Plants.PZ{i}=EmptyPlant.PZ;
        else
            % Set Plant #i to be of Plant type ki
            intmodel.Plants.Pmin(i)=Plants.Pmin(ki);
            intmodel.Plants.Pmax(i)=Plants.Pmax(ki);
            intmodel.Plants.alpha(i)=Plants.alpha(ki);
            intmodel.Plants.beta(i)=Plants.beta(ki);
            intmodel.Plants.gamma(i)=Plants.gamma(ki);
            intmodel.Plants.PZ{i}=Plants.PZ{ki};
        end
    end
    
    intmodel.B=extmodel.B;
    intmodel.B0=extmodel.B0;
    intmodel.B00=extmodel.B00;
    
end