%
% Copyright (c) 2015, Yarpiz (www.yarpiz.com)
% All rights reserved. Please read the "license.txt" for license terms.
%
% Project Code: YPAP113
% Project Title: Solving Economic Dispatching using Nested PSO in MATLAB
% Publisher: Yarpiz (www.yarpiz.com)
% 
% Developer: S. Mostapha Kalami Heris (Member of Yarpiz Team)
% 
% Contact Info: sm.kalami@gmail.com, info@yarpiz.com
%

function out=ModelCalculations(P,model)

    alpha=model.Plants.alpha;
    beta=model.Plants.beta;
    gamma=model.Plants.gamma;
    
    C=alpha+beta.*P+gamma.*P.*P;
    
    CTotal=sum(C);
    
    B=model.B;
    B0=model.B0;
    B00=model.B00;
    
    PL=P*B*P'+B0*P'+B00;
    
    PTotal=sum(P);
    
    PD=model.PD;
    
    PowerBalanceViolation=max(1-(PTotal-PL)/PD,0);
    
    q=1000000;
    z=CTotal+q*PowerBalanceViolation;
    
    out.P=P;
    out.PTotal=PTotal;
    out.C=C;
    out.CTotoal=CTotal;
    out.PL=PL;
    out.PowerBalanceViolation=PowerBalanceViolation;
    out.z=z;

end